@@ -186,17 +186,20 @@ def batch_create_data_rows(client, dataset, global_key_to_upload_dict, skip_dupl
     if payload:
         loop_counter = 0
         while len(payload['notFoundGlobalKeys']) != len(global_keys_list):
+            if not payload:
+                break
             # If global keys are taken by deleted data rows, clearn global keys from deleted data rows
             if payload['deletedDataRowGlobalKeys']:
                 client.clear_global_keys(payload['deletedDataRowGlobalKeys'])
                 payload = __check_global_keys(client, global_keys_list)
             # If global keys are taken by existing data rows, either skip them on upload or update the global key to have a "_{loop_counter}" suffix
+            if not payload:
+                break
             if payload['fetchedDataRows']:
                 loop_counter += 1
                 for i in range(0, len(payload['fetchedDataRows'])):
                     current_global_key = str(global_keys_list[i])
                     new_global_key = f"{current_global_key[:-3]}__{loop_counter}" if current_global_key[-3:-1] == "__" else f"{current_global_key}__{loop_counter}"
-                    print(new_global_key)
                     if payload['fetchedDataRows'][i] != "":
                         if skip_duplicates:
                             del global_key_to_upload_dict[current_global_key] # Delete this data_row_upload_dict from your upload_dict
@@ -219,7 +222,7 @@ def batch_create_data_rows(client, dataset, global_key_to_upload_dict, skip_dupl
             else:
                 print(f'Data Row Creation Error: {errors[0]}')
             return errors
-    return False
+    return []
 
 def upsert_function(upsert_dict_bytes, global_key_col, metadata_value_col):
     """ Nested UDF Functionality upsert metadata in Labelbox and in the pyspark dataframe
@@ -237,9 +240,9 @@ def upsert_function(upsert_dict_bytes, global_key_col, metadata_value_col):
         return_value = metadata_value_col
     return return_value                
 
-def metadata_upsert_udf():
+def metadata_upsert_udf(**kwargs):
     """ Returns a UDF that will upsert a column given a dictionary where {key=column_name : value=new_value}
     Returns:
         UDF object to-be-run using: spark_dataframe.withColumn(col_name, udf(**kwargs))
     """      
-    return udf(upsert_function(), StringType())
+    return udf(upsert_function(**kwargs), StringType())
